@@ -55,6 +55,7 @@ void GetHardwareInfo(int fd, struct hw_stat *hw)
 		{
 			if (strncmp(temp_string, "Processor", strlen("Processor")) == 0)
 			{
+			    // This branch is historic (??)
 				if (strncmp(temp_string2, "Intel sa110", strlen("Intel sa110")) == 0)
 				{
 					strcpy(vendor, "Intel");
@@ -74,8 +75,10 @@ void GetHardwareInfo(int fd, struct hw_stat *hw)
                                 {
 				    strcpy(vendor, implementer[++i]);
 		                    found=1;
+				    processors++;
 				}
 				i += 2;
+
 			    }
 			}
 
