@@ -13,7 +13,7 @@
 	Copyright (C) 2002 
 	John R. Daily <jdaily@progeny.com>
 
-	Copyright (C) 2005 
+	Copyright (C) 2005,2016 
 	Helge Kreutzmann <debian@helgefjell.de>
 
         Version Author  Date            Comments
@@ -24,6 +24,7 @@
         1.0.3   OPAL    20030417	Fixed so that it compiles.
 	1.0.4   KRE     20050318        For now always use family as model (improve later)
 	1.0.5   KRE     20051118        Include <string.h>
+	1.0.6   KRE     20160918        Determine fastest CPU
 
         This is the Intel ia64 port of linuxinfo
 */
@@ -114,7 +115,10 @@ void GetHardwareInfo(int fd, struct hw_stat *hw)
 				strcpy(family, temp_string2);
 
 			if (strncasecmp(temp_string, "cpu MHz", strlen("cpu MHz")) == 0)
-				tempMHz = atol(temp_string2);
+			{
+				if (atol(temp_string2) > tempMHz)
+					tempMHz = atol(temp_string2);
+			}
 
 			if (strncasecmp(temp_string, "bogomips", strlen("bogomips")) == 0)
 				bogomips = bogomips + atof(temp_string2);
