@@ -92,6 +92,7 @@ static char *models[] =
 	"AMD Opteron(tm) Processor 244", "Opteron",
 	"AMD Opteron(tm) Processor 246", "Opteron",
 	"AMD Opteron(tm) Processor 248", "Opteron",
+	"AMD Opteron 23xx (Gen 3 Class Opteron)", "Opteron Gen 3",
 	"AMD Sempron(tm)   2300+", "Sempron",
 	"AMD Sempron(tm)   2600+", "Sempron",
 	"AMD Athlon(tm) 64 Processor 2800+", "x86_64",
@@ -135,6 +136,7 @@ static char *models[] =
 	"Intel(R) Xeon(TM) CPU 3.20GHz", "Xeon",
 	"Intel(R) Xeon(TM) CPU 3.40GHz", "Xeon",
 	"Intel(R) Xeon(TM) CPU 3.60GHz", "Xeon",
+	"Intel(R) Xeon(R) CPU           E5345  @ 2.33GHz","Xeon",
 	"Intel(R) Xeon(R) CPU           L5420  @ 2.50GHz","Xeon",
         "Celeron (Coppermine)", "Celeron (Coppermine)",
         "Celeron (Mendocino)", "Celeron (Mendocino)",
@@ -157,6 +159,7 @@ static char *models[] =
 	"Intel(R) Core(TM) i5-4210U CPU @ 1.70GHz", "Core i5",
 	"Intel(R) Core(TM) i5-6200U CPU @ 2.30GHz", "Core i5",
 	"Intel(R) Core(TM) i5-6600 CPU @ 3.30GHz", "Core i5",
+	"Intel(R) Core(TM) i7-6600U CPU @ 2.60GHz", "Core i7",
 	"Genuine Intel(R) CPU            2140  @ 1.60GHz", "Pentium 4",
 	"Intel(R) Atom(TM) CPU N450   @ 1.66GHz", "Atom",
         NULL, NULL
